{ inputs, config, lib, pkgs, modulesPath, ... }:

{
  imports =
    [ 
      inputs.hardware.nixosModules.common-cpu-intel
      inputs.hardware.nixosModules.common-gpu-nvidia
    
      (modulesPath + "/installer/scan/not-detected.nix")
    ];

  boot.initrd.availableKernelModules = [ "xhci_pci" "ehci_pci" "ahci" "usbhid" "usb_storage" "sd_mod" "sdhci_pci" ];
  boot.initrd.kernelModules = [ ];
  boot.kernelModules = [ "kvm-intel" ];
  boot.extraModulePackages = [ ];
  
  boot.loader = {
    # use systemd-boot over grub
    grub.enable = lib.mkForce false;
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  # nvidia bullshit. Wow
  # i really, *really* wish i had an AMD card rn
  hardware.nvidia = {
    # this will cause problems down the line, but man i need that explicit sync ASAP
    package = config.boot.kernelPackages.nvidiaPackages.beta;
    modesetting.enable = true;
    # powermanagement breaks suspend i guess??
    #
    # im about to suspend lets see if turning it off fixed it
    #
    # it did not !! this time our computer actually shut off fully but..
    # hyprland turned into an eldrich horror then crashed. Lets just not for now!
    # powerManagement.enable = false;

    prime = {
      offload = {
        enable = true;
      };

      intelBusId = "PCI:0:2:0";
      nvidiaBusId = "PCI:1:0:0";
    };
  };
  hardware.opengl = {
    enable = true;
    driSupport = true;
    driSupport32Bit = true;
  };

  fileSystems."/" =
    { device = "/dev/disk/by-uuid/08cfbb11-5943-4627-a2fc-fd41ce578027";
      fsType = "ext4";
    };

  fileSystems."/boot" =
    { device = "/dev/disk/by-uuid/C321-2746";
      fsType = "vfat";
    };

  swapDevices =
    [ { device = "/dev/disk/by-uuid/04eddb76-4925-4192-a472-1c2c7e4ac9f7"; }
    ];

  # Enables DHCP on each ethernet and wireless interface. In case of scripted networking
  # (the default) this is the recommended approach. When using systemd-networkd it's
  # still possible to use this option, but it's recommended to use it in conjunction
  # with explicit per-interface declarations with `networking.interfaces.<interface>.useDHCP`.
  networking.useDHCP = lib.mkDefault true;
  # networking.interfaces.end0.useDHCP = lib.mkDefault true;
  # networking.interfaces.wlan0.useDHCP = lib.mkDefault true;

  nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";
  hardware.cpu.intel.updateMicrocode = lib.mkDefault config.hardware.enableRedistributableFirmware;
}
